@@ -78,7 +78,7 @@ pub struct Parameter {
 
 #[derive(PartialEq, Clone, Default, Debug, XDROut, XDRIn)]
 pub struct Account {
-    #[array(var = 2147483647)]
+    #[array(var = 32)]
     pub permissionedKeys: Vec<ID>,
 }
 
@@ -107,9 +107,6 @@ pub struct Block {
 
 #[derive(PartialEq, Clone, Default, Debug, XDROut, XDRIn)]
 pub struct BlockHeader {
-    #[array(var = 256)]
-    pub timestamp: String,
-
     pub blockHeight: u64,
 
     pub transactionHeight: u64,
@@ -123,8 +120,6 @@ pub struct BlockHeader {
     pub stateRoot: Hash,
 
     pub previousHeader: Hash,
-
-    pub blockProducerAddress: ID,
 }
 
 // End struct section
@@ -197,10 +192,7 @@ pub struct StatusInfo {
 pub struct ChannelConfig {
     pub owner: ID,
 
-    #[array(var = 200)]
-    pub channelName: String,
-
-    #[array(var = 200)]
+    #[array(var = 32)]
     pub admins: Vec<ID>,
 }
 
@@ -370,12 +362,12 @@ pub struct StateStatus {
 
 #[derive(PartialEq, Clone, Default, Debug, XDROut, XDRIn)]
 pub struct BlockLookupRequest {
-    pub ID: Identifier,
+    pub identifier: Identifier,
 }
 
 #[derive(PartialEq, Clone, Default, Debug, XDROut, XDRIn)]
 pub struct BlockHeaderLookupRequest {
-    pub ID: Identifier,
+    pub identifier: Identifier,
 }
 
 #[derive(PartialEq, Clone, Default, Debug, XDROut, XDRIn)]
